@@ -206,7 +206,7 @@ doIncludeLine(uchar **pp, __attribute__((unused)) void* pVal)
 	 * Required by doIncludeDirectory().
 	 */
 	result = glob(pattern, GLOB_MARK, NULL, &cfgFiles);
-	if(result != 0) {
+	if(result == GLOB_NOSPACE || result == GLOB_ABORTED) {
 		char errStr[1024];
 		rs_strerror_r(errno, errStr, sizeof(errStr));
 		errmsg.LogError(0, RS_RET_FILE_NOT_FOUND, "error accessing config file or directory '%s': %s",
@@ -395,6 +395,7 @@ processConfFile(uchar *pConfFile)
 	uchar cbuf[CFGLNSIZ];
 	uchar *cline;
 	int i;
+	int bHadAnError = 0;
 	ASSERT(pConfFile != NULL);
 
 	if((cf = fopen((char*)pConfFile, "r")) == NULL) {
@@ -456,6 +457,7 @@ processConfFile(uchar *pConfFile)
 			snprintf((char*)szErrLoc, sizeof(szErrLoc) / sizeof(uchar),
 				 "%s, line %d", pConfFile, iLnNbr);
 			errmsg.LogError(0, NO_ERRCODE, "the last error occured in %s", (char*)szErrLoc);
+			bHadAnError = 1;
 		}
 	}
 
@@ -475,6 +477,10 @@ finalize_it:
 		dbgprintf("error %d processing config file '%s'; os error (if any): %s\n",
 			iRet, pConfFile, errStr);
 	}
+
+	if(bHadAnError && (iRet == RS_RET_OK)) { /* a bit dirty, enhance in future releases */
+		iRet = RS_RET_NONFATAL_CONFIG_ERR;
+	}
 	RETiRet;
 }
 
@@ -979,8 +985,7 @@ static rsRetVal cflineProcessTagSelector(uchar **pline)
 	if(**pline != '\0' && **pline == '*' && *(*pline+1) == '\0') {
 		dbgprintf("resetting programname filter\n");
 		if(pDfltProgNameCmp != NULL) {
-			if((iRet = rsCStrSetSzStr(pDfltProgNameCmp, NULL)) != RS_RET_OK)
-				return(iRet);
+			rsCStrDestruct(&pDfltProgNameCmp);
 		}
 	} else {
 		dbgprintf("setting programname filter to '%s'\n", *pline);
