@@ -74,13 +74,13 @@ typedef struct s_dynaFileCacheEntry dynaFileCacheEntry;
 /* globals for default values */
 static int iDynaFileCacheSize = 10; /* max cache for dynamic files */
 static int fCreateMode = 0644; /* mode to use when creating files */
-static int fDirCreateMode = 0644; /* mode to use when creating files */
+static int fDirCreateMode = 0700; /* mode to use when creating files */
 static int	bFailOnChown;	/* fail if chown fails? */
 static uid_t	fileUID;	/* UID to be used for newly created files */
 static uid_t	fileGID;	/* GID to be used for newly created files */
 static uid_t	dirUID;		/* UID to be used for newly created directories */
 static uid_t	dirGID;		/* GID to be used for newly created directories */
-static int	bCreateDirs;	/* auto-create directories for dynaFiles: 0 - no, 1 - yes */
+static int	bCreateDirs = 1;/* auto-create directories for dynaFiles: 0 - no, 1 - yes */
 static int	bEnableSync = 0;/* enable syncing of files (no dash in front of pathname in conf): 0 - no, 1 - yes */
 static uchar	*pszTplName = NULL; /* name of the default template to use */
 /* end globals for default values */
@@ -128,7 +128,7 @@ ENDisCompatibleWithFeature
 BEGINdbgPrintInstInfo
 CODESTARTdbgPrintInstInfo
 	if(pData->bDynamicName) {
-		printf("[dynamic]\n\ttemplate='%s'"
+		dbgprintf("[dynamic]\n\ttemplate='%s'"
 		       "\tfile cache size=%d\n"
 		       "\tcreate directories: %s\n"
 		       "\tfile owner %d, group %d\n"
@@ -142,9 +142,9 @@ CODESTARTdbgPrintInstInfo
 			pData->bFailOnChown ? "yes" : "no"
 			);
 	} else { /* regular file */
-		printf("%s", pData->f_fname);
+		dbgprintf("%s", pData->f_fname);
 		if (pData->fd == -1)
-			printf(" (unused)");
+			dbgprintf(" (unused)");
 	}
 ENDdbgPrintInstInfo
 
@@ -803,7 +803,7 @@ static rsRetVal resetConfigVariables(uchar __attribute__((unused)) *pp, void __a
 	bFailOnChown = 1;
 	iDynaFileCacheSize = 10;
 	fCreateMode = 0644;
-	fDirCreateMode = 0644;
+	fDirCreateMode = 0700;
 	bCreateDirs = 1;
 	bEnableSync = 0;
 	if(pszTplName != NULL) {
